##  Transformation Templates
SAP LeanIX Architecture and Road Map Planning provides predefined templates to cover the most common changes for applications and interfaces. The templates provide sufficient context to help you easily complete them. As you fill out a template, the system automatically aggregates the impacts associated with each Transformation. Additionally, each template can be customized by defining additional impacts, but such customization is not obligatory.
The following table lists the available predefined templates:
Transformation Template | Purpose
---|---
Introduce New Application | Introduce a new Application to several Organizations and/or Business Capabilities.
Change Application Technology | Upgrade or replace a technology of an Application.
Rollout Application | Roll out an existing Application to several Organization and/or Business Capabilities.
Discontinue Application | Move an Application into phase out.
Withdraw Application | Remove an Application from a selection of Organization and/or Business Capabilities.
Decommission Application | Move an Application to end of life.
Introduce New Interface | Introduce a new Interface.
Decommission Interface | Move an Interface to end of life.
Change Interface Technology | Upgrade or replace a technology of an Interface
Change Data Transfer | Change the data that is transferred via an Interface.


In addition to predefined Transformations, you can also define Custom Transformations tailored to document specific architectural changes according to your requirements.
